@@ -20,7 +20,7 @@ from nuitka.utils.FileOperations import (
     getReportPath,
     isFilenameBelowPath,
 )
-from nuitka.utils.Importing import getSharedLibrarySuffixes
+from nuitka.utils.Importing import getExtensionModuleSuffixes
 from nuitka.utils.Json import loadJsonFromFilename
 from nuitka.utils.SharedLibraries import (
     callInstallNameTool,
@@ -255,7 +255,7 @@ def _resolveBinaryPathDLLsMacOS(
         # extension module name, so use that if it exists, and some versioned
         # DLL dependencies do not matter.
         if python_version >= 0x300:
-            so_suffixes = getSharedLibrarySuffixes()[:-1]
+            so_suffixes = getExtensionModuleSuffixes()[:-1]
 
             specific_suffix = so_suffixes[0]
             abi_suffix = so_suffixes[1]
@@ -359,7 +359,7 @@ def _resolveBinaryPathDLLsMacOS(
 
 
 def _detectBinaryRPathsMacOS(original_dir, binary_filename):
-    stdout = getOtoolListing(binary_filename)
+    stdout = getOtoolListing(filename=binary_filename, cached=True)
 
     lines = stdout.split(b"\n")
 
